package com.nanyan.securitylink.service;

import com.alibaba.fastjson.JSONObject;
import com.nanyan.securitylink.config.AppConfig;
import com.nanyan.securitylink.entity.WeChatMsg;
import com.nanyan.securitylink.vo.Response;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.nio.charset.StandardCharsets;

@Slf4j
@Service
public class AlertService {
    @Autowired
    RestTemplate restTemplate;
    @Autowired
    AppConfig appConfig;
    public boolean sendAlertMsg(String msg){
        WeChatMsg weChatMsg = buildAlertMsg(msg);
        log.info("发送企业微信msg:{}", JSONObject.toJSONString(weChatMsg));
        HttpEntity<String> entity = new HttpEntity<>(JSONObject.toJSONString(weChatMsg),getHeader().getHeaders());
        ResponseEntity<Response> response = restTemplate.postForEntity(String.format("%s/api/v1/msg", appConfig.getAlertHost()), entity, Response.class);
        log.info("发送企业微信返回:{}", JSONObject.toJSONString(response));
        return true;
    }

    private WeChatMsg buildAlertMsg(String content) {
        if(content.length()>4000){
            content = content.substring(0,4000);
        }
        WeChatMsg weChatMsg = new WeChatMsg();
        weChatMsg.setMsgtype("markdown");
        WeChatMsg.MsgText msgText = new WeChatMsg.MsgText();
        String builder = "## dify异常\n" +
                ">内容:<font color=\"comment\"> " + content + "</font>\n";
        msgText.content = builder;
        weChatMsg.setMarkdown(msgText);
        return weChatMsg;
    }

    private HttpEntity getHeader(){
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.set("Content-Type","application/json");
        return new HttpEntity<>(httpHeaders);
    }
}
