package com.nanyan.securitylink.service;

import com.alibaba.fastjson.JSONObject;
import com.nanyan.securitylink.config.FailoverProperties;
import com.nanyan.securitylink.config.FailoverProperties.UriConfig;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import lombok.RequiredArgsConstructor;
import org.springframework.util.AntPathMatcher;
import java.util.Optional;

@Slf4j
@Service
@RequiredArgsConstructor
public class TokenRouteMappingService {

    private final FailoverProperties failoverProperties;
    private final AntPathMatcher pathMatcher = new AntPathMatcher();

    public Optional<UriConfig> findMatchingUriConfig(String token, String sourceUri) {
        Optional<UriConfig> first = failoverProperties.getTokenMappings().stream()
                .filter(mapping -> mapping.getTokens().contains(token))
                .flatMap(mapping -> mapping.getUriConfigs().stream())
                .filter(uriConfig -> pathMatcher.match(uriConfig.getSourceUri(), sourceUri))
                .findFirst();
        if(first.isPresent()){
            log.info("映射的配置:{}", JSONObject.toJSONString(first));
        }else {
            log.info("token:{} sourceUri:{} 未配置", token, sourceUri);
        }
        return first;
    }

    public String resolveTargetUri(String sourceUri, UriConfig uriConfig) {
        if (uriConfig.getSourceUri().contains("*")) {
            String remaining = pathMatcher.extractPathWithinPattern(
                    uriConfig.getSourceUri(), sourceUri);
            return uriConfig.getTargetUri().replace("{remaining}", remaining);
        }
        return uriConfig.getTargetUri();
    }
}